/*
 * resolv_numbers.h -- DNS assigned numbers
 * Copyright (C) 2001  Andrew Main
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef _LINUX_RESOLV_NUMBERS_H
#define _LINUX_RESOLV_NUMBERS_H 1

/*
 * This file defines macro names for assigned domain class and resource
 * record type numbers in the DNS protocol.  This is intended for use
 * with the kernel-internal resolver interface, resolv.h.
 *
 * Only end-user data classes and RRtypes are named here.  Meta-types
 * (which have significance in a particular DNS protocol transaction)
 * and DNS metadata types (which have significance only within the
 * operation of the DNS protocol) are not named.
 */

/* domain classes */

#define C_IN		1
#define C_CH		3
#define C_HS		4
/*      C_NONE		254 */
/*      C_ANY		255 */

/* resource record types */

#define T_A		1
/*      T_NS		2 */
#define T_MD		3
#define T_MF		4
/*      T_CNAME		5 */
/*      T_SOA		6 */
#define T_MB		7
#define T_MG		8
#define T_MR		9
#define T_NULL		10
#define T_WKS		11
#define T_PTR		12
#define T_HINFO		13
#define T_MINFO		14
#define T_MX		15
#define T_TXT		16
#define T_RP		17
#define T_AFSDB		18
#define T_X25		19
#define T_ISDN		20
#define T_RT		21
#define T_NSAP		22
#define T_NSAP_PTR	23
/*      T_SIG		24 */
/*      T_KEY		25 */
#define T_PX		26
#define T_GPOS		27
#define T_AAAA		28
#define T_LOC		29
/*      T_NXT		30 */
#define T_EID		31
#define T_NIMLOC	32
#define T_SRV		33
#define T_ATMA		34
#define T_NAPTR		35
#define T_KX		36
#define T_CERT		37
/*      T_A6		38 */
/*      T_DNAME		39 */
#define T_SINK		40
/*      T_OPT		41 */
#define T_APL		42
#define T_UINFO		100
#define T_UID		101
#define T_GID		102
#define T_UNSPEC	103
/*      T_ADDRS		248 */
/*      T_TKEY		249 */
/*      T_TSIG		250 */
/*      T_IXFR		251 */
/*      T_AXFR		252 */
/*      T_MAILB		253 */
/*      T_MAILA		254 */
/*      T_ANY		255 */

#endif /* !_LINUX_RESOLV_NUMBERS_H */
